summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c')
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c
index 17ff6748..2ea733ac 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/scheduler.c
@@ -148,7 +148,7 @@ gpointer rtp_scheduler_schedule(gpointer psched)
g_mutex_unlock(sched->lock);
/* now while the scheduler is going to sleep, the other threads can compute their
- result mask and see if they have to leave, or to wait for next tick*/
+ result tqmask and see if they have to leave, or to wait for next tick*/
//g_message("scheduler: sleeping.");
timer->timer_do();
sched->time_+=sched->timer_inc;
@@ -174,10 +174,10 @@ void rtp_scheduler_add_session(RtpScheduler *sched, RtpSession *session)
if (sched->max_sessions==0){
g_error("rtp_scheduler_add_session: max_session=0 !");
}
/* find a free pos in the session mask*/
for (i=0;i<sched->max_sessions;i++){
if (!ORTP_FD_ISSET(i,&sched->all_sessions.rtpset)){
- session->mask_pos=i;
+ session->tqmask_pos=i;
session_set_set(&sched->all_sessions,session);
/* make a new session scheduled not blockable if it has not started*/
if (session->flags & RTP_SESSION_RECV_NOT_STARTED)
@@ -229,7 +229,7 @@ void rtp_scheduler_remove_session(RtpScheduler *sched, RtpSession *session)
}
}
rtp_session_unset_flag(session,RTP_SESSION_IN_SCHEDULER);
/* delete the bit in the mask */
session_set_clr(&sched->all_sessions,session);
rtp_scheduler_unlock(sched);
}
@@ -174,10 +174,10 @@ void rtp_scheduler_add_session(RtpScheduler *sched, RtpSession *session)
g_error("rtp_scheduler_add_session: max_session=0 !");
}
- /* find a free pos in the session mask*/
+ /* find a free pos in the session tqmask*/
for (i=0;i<sched->max_sessions;i++){
if (!ORTP_FD_ISSET(i,&sched->all_sessions.rtpset)){
@@ -229,7 +229,7 @@ void rtp_scheduler_remove_session(RtpScheduler *sched, RtpSession *session)
}
rtp_session_unset_flag(session,RTP_SESSION_IN_SCHEDULER);
- /* delete the bit in the mask */
+ /* delete the bit in the tqmask */
session_set_clr(&sched->all_sessions,session);
rtp_scheduler_unlock(sched);